pub enum DispatchOperationKind {
ConversationOpened,
WorkerSelected,
MessageSent,
MessageReceived,
WorkerExited,
ConversationClosed,
}Expand description
Recorder-visible dispatch channel operation.
Variants
ConversationOpened
The dispatch conversation boundary opened on the task queue channel.
WorkerSelected
The configured routing function selected a worker.
MessageSent
The activity request was sent through the conversation.
MessageReceived
A worker response was received through the conversation.
WorkerExited
A linked worker process exited while the conversation was waiting.
ConversationClosed
The dispatch conversation boundary closed.