pub struct RoutingFunctionDispatchRouter { /* private fields */ }Expand description
Router adapter backed by the active liminal routing function slot.
Implementations
Sourceimpl RoutingFunctionDispatchRouter
impl RoutingFunctionDispatchRouter
Sourcepub const fn new(slot: Arc<RoutingSlot>, executor: SupervisedExecutor) -> Self
pub const fn new(slot: Arc<RoutingSlot>, executor: SupervisedExecutor) -> Self
Creates a router using the supplied routing slot and supervised executor.