DispatchRecorder

Trait DispatchRecorder 

pub trait DispatchRecorder:
    Debug
    + Send
    + Sync {
    // Required methods
    fn replay_outcome(
        &self,
        channel_name: &str,
        request: &ActivityRequest,
    ) -> Result<Option<RecordedDispatchOutcome>, AionSurfaceError>;
    fn record(
        &self,
        operation: DispatchOperation,
    ) -> Result<(), AionSurfaceError>;
}
Recorder seam implemented by Aion’s existing record/replay layer.

Required Methods

fn replay_outcome( &self, channel_name: &str, request: &ActivityRequest, ) -> Result<Option<RecordedDispatchOutcome>, AionSurfaceError>

Returns a recorded outcome during replay, before any live conversation is opened.

Errors

Returns an error if the recorder cannot read replay data.

fn record(&self, operation: DispatchOperation) -> Result<(), AionSurfaceError>

Records one dispatch channel operation.

Errors

Returns an error if the recorder cannot append the operation.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors