pub enum ActivityResult {
Completed {
output: Payload,
},
Failed {
error: AionSurfaceError,
},
}Expand description
Activity dispatch result returned by an Aion dispatch conversation.
Variants
Completed
Activity completed with a type-erased output payload.
Failed
Activity failed with integration-surface diagnostic context.
Fields

error: AionSurfaceErrorTrait Implementations
Sourceimpl Clone for ActivityResult
impl Clone for ActivityResult
Sourcefn clone(&self) -> ActivityResult
fn clone(&self) -> ActivityResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ActivityResult
impl Debug for ActivityResult
impl Eq for ActivityResult
Sourceimpl PartialEq for ActivityResult
impl PartialEq for ActivityResult
Sourcefn eq(&self, other: &ActivityResult) -> bool
fn eq(&self, other: &ActivityResult) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ActivityResult