pub enum SchemaValidationError {
InvalidJson {
source: Error,
},
InvalidSchema {
message: String,
},
Mismatch {
message: String,
},
NotObjectSchema,
EmptyFieldName,
InvalidProperties,
InvalidRequired,
PayloadNotObject,
Serialize {
source: Error,
},
}Expand description
Errors returned while compiling schemas, validating payloads, or evolving schemas.
Variants
InvalidJson
The payload was not syntactically valid JSON.
InvalidSchema
The JSON Schema definition could not be compiled.
Mismatch
The payload did not satisfy the JSON Schema definition.
NotObjectSchema
Schema evolution can only add fields to object schemas.
EmptyFieldName
Schema evolution field names must be non-empty.
InvalidProperties
The schema’s properties member was not an object.
InvalidRequired
The schema’s required member was not an array of strings.
PayloadNotObject
The payload cannot receive object-field defaults because it is not an object.
Serialize
The normalized JSON payload could not be serialized for delivery.