pub struct CheckpointDriver { /* private fields */ }Expand description
Drives cursor checkpoints according to the channel’s configured policy.
Implementations
Sourceimpl CheckpointDriver
impl CheckpointDriver
Sourcepub fn new(policy: impl Into<CheckpointPolicy>) -> Self
pub fn new(policy: impl Into<CheckpointPolicy>) -> Self
Creates a checkpoint driver from a checkpoint policy or full durability config.
Sourcepub const fn from_policy(policy: CheckpointPolicy) -> Self
pub const fn from_policy(policy: CheckpointPolicy) -> Self
Creates a checkpoint driver from an explicit checkpoint policy.
Sourcepub const fn from_config(config: DurabilityConfig) -> Self
pub const fn from_config(config: DurabilityConfig) -> Self
Creates a checkpoint driver from a durability configuration.
Sourcepub const fn policy(&self) -> CheckpointPolicy
pub const fn policy(&self) -> CheckpointPolicy
Returns the active checkpoint policy.
Sourcepub const fn messages_since_last_checkpoint(&self) -> usize
pub const fn messages_since_last_checkpoint(&self) -> usize
Returns the number of processed messages since the last successful checkpoint.
Sourcepub const fn pending_offset(&self) -> Option<u64>
pub const fn pending_offset(&self) -> Option<u64>
Returns the latest processed offset waiting to be checkpointed.
Sourcepub async fn record_processed(
&mut self,
cursor: &mut ConsumerCursor,
store: &dyn DurableStore,
next_offset: u64,
) -> Result<(), DurabilityError>
pub async fn record_processed( &mut self, cursor: &mut ConsumerCursor, store: &dyn DurableStore, next_offset: u64, ) -> Result<(), DurabilityError>
Records one processed message and checkpoints if the configured policy requires it.
next_offset is the partition offset from which the consumer should resume after the
processed message. The driver delegates all persistence to ConsumerCursor::checkpoint.
Errors
Returns cursor checkpoint errors from the store, or a configuration error for an invalid raw batch policy.
Sourcepub async fn flush(
&mut self,
cursor: &mut ConsumerCursor,
store: &dyn DurableStore,
) -> Result<(), DurabilityError>
pub async fn flush( &mut self, cursor: &mut ConsumerCursor, store: &dyn DurableStore, ) -> Result<(), DurabilityError>
Flushes any processed offset that is waiting to be checkpointed.
Errors
Returns cursor checkpoint errors from the store, or a configuration error for an invalid raw batch policy.