pub struct DedupSweepReport { /* private fields */ }Expand description
Summary produced by a dedup TTL sweep.
Implementations
Sourceimpl DedupSweepReport
impl DedupSweepReport
Sourcepub const fn scanned_entries(self) -> usize
pub const fn scanned_entries(self) -> usize
Number of scanned stored dedup events.
Sourcepub const fn expired_entries(self) -> usize
pub const fn expired_entries(self) -> usize
Number of logical cache entries tombstoned by the sweep.
Sourcepub const fn retained_entries(self) -> usize
pub const fn retained_entries(self) -> usize
Number of latest active entries retained after the sweep.