pub enum PolicyEvent {
Action {
channel_id: String,
action: PolicyAction,
triggered_at: SystemTime,
},
ScaleConsumer {
signal: ScaleSignal,
triggered_at: SystemTime,
},
}Expand description
Typed pressure policy event emitted by the enforcer.
Variants
Action
A policy action became active for a channel pressure update.
Fields

action: PolicyActionAction selected by the channel policy configuration.

triggered_at: SystemTimeWall-clock time when the enforcer emitted this event.
ScaleConsumer
A scale-consumer policy emitted a scaling signal for external orchestration.
Fields

signal: ScaleSignalSignal payload for the external orchestrator.

triggered_at: SystemTimeWall-clock time when the enforcer emitted this event.