pub struct ChannelPolicyConfig { /* private fields */ }Expand description
Ordered pressure escalation policy for a channel.
Implementations
Sourceimpl ChannelPolicyConfig
impl ChannelPolicyConfig
Sourcepub fn new(policies: Vec<PressurePolicy>) -> Self
pub fn new(policies: Vec<PressurePolicy>) -> Self
Creates a channel policy configuration ordered by ascending threshold.
Sourcepub fn policies(&self) -> &[PressurePolicy]
pub fn policies(&self) -> &[PressurePolicy]
Returns the configured pressure policies in escalation order.
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns whether this channel has no configured pressure policies.
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Returns the number of configured pressure policies for this channel.
Sourcepub fn actions_for_pressure(&self, pressure: f64) -> Vec<PolicyAction>
pub fn actions_for_pressure(&self, pressure: f64) -> Vec<PolicyAction>
Returns every action active for the supplied channel pressure score.