Module codec

Module codec 

Functions

decode
Decode one complete frame from a byte buffer.
encode
Encode a frame into the provided byte buffer, returning bytes written.
encoded_len
Return the number of bytes needed to encode a frame.