encoded_len

Function encoded_len 

pub fn encoded_len(frame: &Frame) -> Result<usize, ProtocolError>
Return the number of bytes needed to encode a frame.

Errors

Returns ProtocolError when the frame violates stream invariants or its payload cannot fit in the protocol’s u32 length fields.