pub struct StreamId(pub u32);Expand description
Stream identifier carried in every frame header.
Stream 0 is reserved for connection-level control frames. Application streams use identifiers 1 and above.
Tuple Fields
0: u32Implementations
Sourceimpl StreamId
impl StreamId
Sourcepub const fn is_control(self) -> bool
pub const fn is_control(self) -> bool
Return true when this stream is the reserved control stream.
Sourcepub const fn is_application(self) -> bool
pub const fn is_application(self) -> bool
Return true when this stream is available for application traffic.