pub struct ProtocolVersion {
pub major: u16,
pub minor: u16,
}Expand description
Protocol version negotiated during the connection handshake.
Fields
major: u16Major protocol version component.
minor: u16Minor protocol version component.
Implementations
Sourceimpl ProtocolVersion
impl ProtocolVersion
Sourcepub const fn new(major: u16, minor: u16) -> Self
pub const fn new(major: u16, minor: u16) -> Self
Create a protocol version from its major and minor components.
Sourcepub const fn serialize(self) -> [u8; 4]
pub const fn serialize(self) -> [u8; 4]
Serialize this version as big-endian major followed by big-endian minor.
Sourcepub const fn to_wire_bytes(self) -> [u8; 4]
pub const fn to_wire_bytes(self) -> [u8; 4]
Serialize this version for wire transport.
Sourcepub fn deserialize(bytes: &[u8]) -> Result<Self, ProtocolError>
pub fn deserialize(bytes: &[u8]) -> Result<Self, ProtocolError>
Deserialize a protocol version from wire bytes.
Errors
Returns ProtocolError::CodecError when bytes is not exactly four bytes long.
Sourcepub fn from_wire_bytes(bytes: &[u8]) -> Result<Self, ProtocolError>
pub fn from_wire_bytes(bytes: &[u8]) -> Result<Self, ProtocolError>
Deserialize a protocol version from wire bytes.
Errors
Returns ProtocolError::CodecError when bytes is not exactly four bytes long.