pub struct RoutingTable { /* private fields */ }Expand description
Concurrent routing table mapping channels to active predicate subscriptions.
Implementations
Sourceimpl RoutingTable
impl RoutingTable
Sourcepub fn register(
&self,
channel: impl Into<String>,
subscription: Subscription,
) -> Arc<Subscription> ⓘ
pub fn register( &self, channel: impl Into<String>, subscription: Subscription, ) -> Arc<Subscription> ⓘ
Registers subscription on channel and returns its shared table handle.
Sourcepub fn remove(&self, channel: &str, subscriber: &SubscriberId) -> bool
pub fn remove(&self, channel: &str, subscriber: &SubscriberId) -> bool
Removes subscriptions for subscriber on channel.
Sourcepub fn resolve(
&self,
channel: &str,
accessor: &dyn FieldAccessor,
) -> Vec<Arc<Subscription>>
pub fn resolve( &self, channel: &str, accessor: &dyn FieldAccessor, ) -> Vec<Arc<Subscription>>
Resolves all subscriptions on channel whose predicates match accessor.