pub struct Subscription {
pub subscriber: SubscriberId,
pub predicate: Predicate,
}Expand description
Active predicate subscription for a channel.
Fields
subscriber: SubscriberIdSubscriber identity that owns this subscription.
predicate: PredicatePredicate that must match for this subscription to receive a message.
Implementations
Sourceimpl Subscription
impl Subscription
Sourcepub const fn new(subscriber: SubscriberId, predicate: Predicate) -> Self
pub const fn new(subscriber: SubscriberId, predicate: Predicate) -> Self
Creates a subscription from a subscriber identity and predicate.