Module codec
liminal
0.2.0
Module codec
Module Items
Functions
In liminal::
protocol
liminal
::
protocol
Module
codec
Functions

decode
Decode one complete frame from a byte buffer.
encode
Encode a frame into the provided byte buffer, returning bytes written.
encoded_
len
Return the number of bytes needed to encode a frame.