pub struct ConsumerStateView {
pub consumer: ConsumerId,
pub current_in_flight: u32,
pub max_in_flight: u32,
pub buffer_depth: u32,
pub affinity_tags: Vec<String>,
}Expand description
Per-consumer state presented to a routing function during execution.
Fields
consumer: ConsumerIdConsumer the state describes.
current_in_flight: u32Messages currently in flight to the consumer.
max_in_flight: u32Maximum messages the consumer will accept in flight.
buffer_depth: u32Depth of the consumer’s pending buffer.
Affinity tags advertised by the consumer.
Implementations
Sourceimpl ConsumerStateView
impl ConsumerStateView
Sourcepub const fn new(
consumer: ConsumerId,
current_in_flight: u32,
max_in_flight: u32,
buffer_depth: u32,
affinity_tags: Vec<String>,
) -> Self
pub const fn new( consumer: ConsumerId, current_in_flight: u32, max_in_flight: u32, buffer_depth: u32, affinity_tags: Vec<String>, ) -> Self
Creates a consumer state view.
Sourcepub const fn available_capacity(&self) -> u32
pub const fn available_capacity(&self) -> u32
Returns the remaining in-flight capacity of the consumer.
Sourcepub const fn has_capacity(&self) -> bool
pub const fn has_capacity(&self) -> bool
Returns true when the consumer can accept at least one more message.
Sourcepub fn has_affinity(&self, tag: &str) -> bool
pub fn has_affinity(&self, tag: &str) -> bool
Returns true when the consumer advertises tag.